==> haskell-snap-server-1.1.2.1-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-AbQfEIqEyw5E5OdLwnt39V
key:                  snap-server-1.1.2.1-AbQfEIqEyw5E5OdLwnt39V
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  24280cc55f1664fb4d23eefa96c31e97
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-AbQfEIqEyw5E5OdLwnt39V
depends:
    attoparsec-0.14.4-6kRuW0kw4gG3rg1QrsDffs base-4.17.2.1
    blaze-builder-0.4.4.1-20XIpZGgNDfHegCCnMhzZO bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9KyZd02Y5otGRG4cekIJFk
    clock-0.8.4-99Usf16qB9g4SiqJsS2GLD containers-0.6.7
    filepath-1.4.2.2 io-streams-1.5.2.2-LJiozhSfmAG2P8ZUE6cv8c
    io-streams-haproxy-1.0.1.0-JwEvMQnh6OC5fEsJbSDqiW
    lifted-base-0.2.3.12-7b4X5WBKUrr5M5yaDsobtl mtl-2.2.2
    network-3.1.4.0-BeHm9PhAGW35QMcXomVSuT
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    snap-core-1.0.5.1-2P1Vjq4GUf9B6r9eQjN5vZ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.4.1-8Y7lpXTSloK7vqVswTol3
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.2.1-314-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-DvhOCoYtMwK85fDwpZQblq
key:                  snap-server-1.1.2.1-DvhOCoYtMwK85fDwpZQblq
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  0864f94371a31890b46b7aa27e71ce91
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-DvhOCoYtMwK85fDwpZQblq
depends:
    attoparsec-0.14.4-D7CECqktDgS2fYWStxbJq3 base-4.17.2.1
    blaze-builder-0.4.4.1-9PaZF0E1n1UJak5ze95yxX bytestring-0.11.5.3
    case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB
    clock-0.8.4-GUokiMAPhE6H4SYGC2IRV1 containers-0.6.7
    filepath-1.4.2.2 io-streams-1.5.2.2-BnxLvKN1XwkGmzDXcimoxX
    io-streams-haproxy-1.0.1.0-HxfGuDsJQQHCVKYItO2Xe9
    lifted-base-0.2.3.12-CaZxFVx2QaKIfHbtq0tB6m mtl-2.2.2
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    snap-core-1.0.5.1-EqcYpBOdZI1BxEOr5GNNhG text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.4.1-51QWcgHKY9Q2M4gdNfLh1f
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
